# eric7.Plugins.VcsPlugins.vcsMercurial.HgStatusMonitorThread

Module implementing the VCS status monitor thread class for Mercurial.

### Global Attributes

None

### Classes

HgStatusMonitorThread | Class implementing the VCS status monitor thread class for Mercurial.

### Functions

None

## HgStatusMonitorThread

Class implementing the VCS status monitor thread class for Mercurial.

### Derived from

VcsStatusMonitorThread

### Class Attributes

None

### Class Methods

None

### Methods

HgStatusMonitorThread | Constructor
__initClient | Private method to initialize the Mercurial client.
_getInfo | Protected method implementing the real info action.
_performMonitor | Protected method implementing the monitoring action.
_shutdown | Protected method performing shutdown actions.

### Static Methods

None

#### HgStatusMonitorThread (Constructor)

HgStatusMonitorThread(interval, project, vcs, parent=None)

Constructor

interval
  new interval in seconds (integer)
project
  reference to the project object (Project)
vcs
  reference to the version control object
parent
  reference to the parent object (QObject)

#### HgStatusMonitorThread.__initClient

__initClient()

Private method to initialize the Mercurial client.

Return:
  tuple containing an OK flag and potentially an error message

Return Type:
  tuple of (bool, str)

#### HgStatusMonitorThread._getInfo

_getInfo()

Protected method implementing the real info action.

Return:
  short info message

Return Type:
  str

#### HgStatusMonitorThread._performMonitor

_performMonitor()

Protected method implementing the monitoring action.

This method populates the statusList member variable with a list of strings giving the status in the first column and the path relative to the project directory starting with the third column. The allowed status flags are:

- "A" path was added but not yet committed
- "M" path has local changes
- "O" path was removed
- "R" path was deleted and then re-added
- "U" path needs an update
- "Z" path contains a conflict
- "?" path is not tracked
- "!" path is missing
- " " path is back at normal

Return:
  tuple of flag indicating successful operation and a status message in case of non successful operation

Return Type:
  tuple of (bool, str)

#### HgStatusMonitorThread._shutdown

_shutdown()

Protected method performing shutdown actions.

Up